import ghmm

# example code for a continuous HMM with gaussian mixtures as emissions


F = ghmm.Float()   # emission domain of this model
A = [[0.25,0.5,0.25],[0.3,0.2,0.5],[0.3,0.3,0.4]]   # transition matrix


# Parameters of emission distributions 
# Interpretation of B matrix for the mixture case (Example with three states and three components each):
#  B = [ 
#      [ ["mu11","mu12","mu13"],["sig11","sig12","sig13"],["w11","w12","w13"]   ],
#      [  ["mu21","mu22","mu23"],["sig21","sig22","sig23"],["w21","w22","w23"]  ],
#      [  ["mu31","mu32","mu33"],["sig31","sig32","sig33"],["w31","w32","w33"]  ],
#      ]

B = [[ [0.0,1.0,2.0],[1.0,2.5,5.5], [0.5,0.3,0.2]],   
     [ [2.0,6.0,1.0],[1.0,0.5,0.7], [0.1,0.5,0.4]],
     [ [4.0,5.0,1.0],[1.0,2.5,2.0], [0.3,0.3,0.4]] ]

pi = [1.0,0.0,0.0]  # initial probabilities per state

model = ghmm.HMMFromMatrices(F,ghmm.GaussianMixtureDistribution(F), A, B, pi)


# modify model parameters (examples)
p = model.getInitial(2)
model.setInitial(2,0.5)
model.setInitial(0,0.5)
 
# re-set transition from state 0 to state 1
trans = model.getTransition(0,1)
model.setTransition(0,1,0.6)

# re-setting emission of state 1
model.setEmission(1,1,[5.0,0.6,0.2])


# re-normalize model parameters
model.normalize()

print model

# sample single sequence of length 50
seq = model.sampleSingle(50)

# sample 10 sequences of length 50
seq_set = model.sample(10,50)

# get log P(seq | model)
logp = model.loglikelihood(seq)

# cacluate viterbi path 
path = model.viterbi(seq)

# train model parameters
model.baumWelch(seq_set,5,0.01)
